#!/usr/bin/env python

'''
File name: example.py
Author: Thomas Haas, KUL (thomas.haas@kuleuven.be)
Date: 14.12.2018

Description:
Examples on how to use the AWESCO datasets.
0) Specify user inputs and retrieve metadata (Domain dimensions, time resolution, scaling)
1) Retrieve volume of streamwise velocity component at discrete time and plot slices of different views
2) Retrieve and plot planes of streamwise velocity component at a discrete height for several time instants
3) Retrieve time series of all three velocity components at specific grid location
4) Retrieve instantaneous velocity interpolated at specific locations in space and time along circular orbit
'''

# Import
import import_dataset as idset
import visualize_dataset as vdset

# Reload
reload(idset)
reload(vdset)

# ================================================ #
# USER INPUT: Case settings
#   - Specify path to dataset
#   - Specify wind class ('c0', 'c1' or 'c2')
#   - Specify time serie ('t1', 't2' or 't3')
#   - Turn on/off visualization functions
#   > Retrieve file name
#   > Retrieve metadata (default)
#   > User-defined scaling: add reference wind speed and height
path = '...'
case = 'c0'
tserie = 't1'
PLOT = True
fname = idset.get_fname(path, case, tserie)
metadata = idset.get_metadata(fname, case)
# metadata = idset.get_metadata(fname, case, u=12.0, z=100.0)
# ================================================= #

# Application 1:
print('=== Application 1 ===')
nt = 600 # Time step of visualization in [0-900]
u = idset.get_volume(metadata, 'u', nt)
if PLOT:
    fig1 = vdset.plot_slices(u, metadata, 'u', nt)

# Application 2:
print('=== Application 2 ===')
u = []
nt = [0,450,900] # Time steps of visualization in [0-900]
for k in range(len(nt)):
    u.append(idset.get_plane(metadata, 'u', nt[k], 'z', metadata['Nz']-1))
if PLOT:
    fig2 = vdset.plot_tplanes(u, metadata, 'u', nt, 'z', metadata['Nz']-1)

# Application 3:
print('=== Application 3 ===')
ind = [50,30,40] # Grid locations of visualization in [0-100, 0-60, 0-80]
V = idset.get_tserie(metadata, ind)
if PLOT:
    fig3 = vdset.plot_tserie(V,metadata, ind)

# Application 4
print('=== Application 4 ===')
N = 3 #Number of cycles
q = idset.get_trajectory(metadata, N)
w = idset.get_wind(metadata, q)
if PLOT:
    fig4 = vdset.plot_trajectory(metadata, q, w)
